@@ -43,9 +43,6 @@ pub(crate) fn render_plot<X: PlotNum, Y: PlotNum>(
         let name_exists = writer
             .elem("text", |d| {
                 d.attr("class", "poloto_text poloto_legend_text")?;
-                d.attr("dominant-baseline", "middle")?;
-                d.attr("text-anchor", "start")?;
-                d.attr("font-size", "large")?;
                 d.attr("x", width - padding / 1.2)?;
                 d.attr("y", paddingy - yaspect_offset + (i as f64) * spacing)
             })?
@@ -82,6 +79,7 @@ pub(crate) fn render_plot<X: PlotNum, Y: PlotNum>(
                     })
                 };
 
+                let precision = extra.precision;
                 render(
                     &mut writer,
                     it,
@@ -91,6 +89,7 @@ pub(crate) fn render_plot<X: PlotNum, Y: PlotNum>(
                         name_exists,
                         colori,
                         legendy1,
+                        precision,
                     },
                 )?;
             }
@@ -100,12 +99,37 @@ pub(crate) fn render_plot<X: PlotNum, Y: PlotNum>(
     Ok(())
 }
 
+struct Hay {
+    num: f64,
+    precision: usize,
+}
+impl Display for Hay {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{:.*}", self.precision, self.num)
+    }
+}
+
+struct Roundf64 {
+    precision: usize,
+}
+
+impl NumFmt for Roundf64 {
+    type K = Hay;
+    fn fmt(&self, num: f64) -> Self::K {
+        Hay {
+            num,
+            precision: self.precision,
+        }
+    }
+}
+
 struct PlotRenderInfo<'a> {
     canvas: &'a Canvas,
     p_type: PlotType,
     name_exists: bool,
     colori: usize,
     legendy1: f64,
+    precision: usize,
 }
 
 fn render<W: fmt::Write>(
@@ -119,6 +143,7 @@ fn render<W: fmt::Write>(
         name_exists,
         colori,
         legendy1,
+        precision,
     } = info;
 
     let Canvas {
@@ -129,6 +154,8 @@ fn render<W: fmt::Write>(
         ..
     } = *canvas;
 
+    let num_fmt = Roundf64 { precision };
+
     match p_type {
         PlotType::Line => {
             if name_exists {
@@ -152,7 +179,7 @@ fn render<W: fmt::Write>(
                 d.attr("class", format_args!("poloto_line poloto{}stroke", colori))?;
                 d.attr("fill", "none")?;
                 d.attr("stroke", "black")?;
-                d.path(|a| render::line(a, it))
+                d.path(|a| render::line(a, it, num_fmt))
             })?;
         }
         PlotType::Scatter => {
@@ -181,7 +208,7 @@ fn render<W: fmt::Write>(
                 d.path(|a| {
                     use tagger::PathCommand::*;
                     for [x, y] in it.filter(|&[x, y]| x.is_finite() && y.is_finite()) {
-                        a.put(M(x, y))?;
+                        a.put(M(num_fmt.fmt(x), num_fmt.fmt(y)))?;
                         a.put(H_(0))?;
                     }
                     Ok(())
@@ -216,8 +243,8 @@ fn render<W: fmt::Write>(
                     for [x, y] in it.filter(|&[x, y]| x.is_finite() && y.is_finite()) {
                         if let Some((lx, ly)) = last {
                             writer.single("rect", |d| {
-                                d.attr("x", lx)?;
-                                d.attr("y", ly)?;
+                                d.attr("x", num_fmt.fmt(lx))?;
+                                d.attr("y", num_fmt.fmt(ly))?;
                                 d.attr("width", (padding * 0.02).max((x - lx) - (padding * 0.02)))?;
                                 d.attr("height", height - paddingy - ly)
                             })?;
@@ -251,7 +278,7 @@ fn render<W: fmt::Write>(
                     "class",
                     format_args!("poloto_linefill poloto{}fill", colori),
                 )?;
-                d.path(|path| render::line_fill(path, it, height - paddingy, true))
+                d.path(|path| render::line_fill(path, it, height - paddingy, true, num_fmt))
             })?;
         }
         PlotType::LineFillRaw => {
@@ -278,7 +305,7 @@ fn render<W: fmt::Write>(
                     "class",
                     format_args!("poloto_linefillraw poloto{}fill", colori),
                 )?;
-                d.path(|path| render::line_fill(path, it, height - paddingy, false))
+                d.path(|path| render::line_fill(path, it, height - paddingy, false, num_fmt))
             })?;
         }
     }
